@@ -366,7 +366,14 @@ def render(
                 input_yaml.name,
                 services=services,
             )
-            cluster_manager.edit_cluster_config(old_conf)
+            # Input yaml contains secrets that we need to include here
+            input_yaml.seek(0)
+            cluster_manager.edit_cluster_config(
+                changes=merge_dicts(
+                    yaml.safe_load(input_yaml),
+                    old_conf if allow_image_overrides else {},
+                )
+            )
             cluster_manager.save()
         finally:
             os.remove(input_yaml.name)
