@@ -113,7 +113,7 @@ def generate_saml(ctx, host=None, metadata_url=None, custom_saml=None):
             settings = json.load(settings_file)
         settings_content = json.dumps(settings, indent=4)
         run_cmd(
-            f'''kubectl create secret generic indico-sso-secrets --from-literal=settings.json="{settings_content}" ''', silent=True
+            f'''kubectl create secret generic indico-sso-secrets --from-literal=settings.json='{settings_content}' ''', silent=True
             )
         ctx.invoke(restart, services=["noct"], contains=False, wait="2m")
         return
