@@ -43,7 +43,7 @@ def ask_for_infra_input(conf):
     )
 
     conf["cluster"].update(
-        {"storage_acct": storage_acct_name, "storage_acct_key": storage_acct_key,}
+        {"storage_acct": storage_acct_name, "storage_acct_key": storage_acct_key}
     )
     conf["clusterVolumes"]["rwx"]["azureFile"]["shareName"] = rwx_fs
     conf["clusterVolumes"]["rox"]["azureFile"]["shareName"] = rox_fs
