@@ -23,9 +23,7 @@ def delete(ctx, service):
             continue
         for _svc in out.splitlines():
             if click.confirm(f"Ok to delete {svc_type} {_svc}"):
-                click.secho(
-                    run_cmd(f"kubectl delete {svc_type} {_svc}"), fg="green",
-                )
+                click.secho(run_cmd(f"kubectl delete {svc_type} {_svc}"), fg="green")
                 updated_svcs.append(_svc)
 
     if updated_svcs:
@@ -71,7 +69,7 @@ def scale(ctx, service, amount):
                         """
                         kubectl patch hpa %s --patch '{"spec":{"minReplicas": %s, "maxReplicas": %s}}'
                         """
-                        % (_svc, amount, amount + 2),
+                        % (_svc, amount, amount + 2)
                     ),
                     fg="green",
                 )
